@@ -82,9 +82,10 @@ struct NautilusFileOperationsProgressDetails {
 	const char *from_prefix;
 	const char *to_prefix;
 
-	gulong bytes_copied;
 	gulong files_total;
-	gulong bytes_total;
+	
+	GnomeVFSFileSize bytes_copied;
+	GnomeVFSFileSize bytes_total;
 
 	/* system time (microseconds) when show timeout was started */
 	gint64 start_time;
@@ -373,7 +374,7 @@ nautilus_file_operations_progress_new (const char *title,
 				       const char *from_prefix,
 				       const char *to_prefix,
 				       gulong total_files,
-				       gulong total_bytes,
+				       GnomeVFSFileSize total_bytes,
 				       gboolean use_timeout)
 {
 	GtkWidget *widget;
@@ -405,7 +406,7 @@ nautilus_file_operations_progress_new (const char *title,
 void
 nautilus_file_operations_progress_set_total (NautilusFileOperationsProgress *progress,
 					     gulong files_total,
-					     gulong bytes_total)
+					     GnomeVFSFileSize bytes_total)
 {
 	g_return_if_fail (NAUTILUS_IS_FILE_OPERATIONS_PROGRESS (progress));
 
@@ -434,7 +435,7 @@ nautilus_file_operations_progress_new_file (NautilusFileOperationsProgress *prog
 					    const char *from_prefix,
 					    const char *to_prefix,
 					    gulong file_index,
-					    gulong size)
+					    GnomeVFSFileSize size)
 {
 	char *progress_count;
 
@@ -489,8 +490,8 @@ nautilus_file_operations_progress_clear (NautilusFileOperationsProgress *progres
 
 void
 nautilus_file_operations_progress_update_sizes (NautilusFileOperationsProgress *progress,
-						gulong bytes_done_in_file,
-						gulong bytes_done)
+						GnomeVFSFileSize bytes_done_in_file,
+						GnomeVFSFileSize bytes_done)
 {
 	g_return_if_fail (NAUTILUS_IS_FILE_OPERATIONS_PROGRESS (progress));
 
@@ -532,7 +533,7 @@ nautilus_file_operations_progress_done (NautilusFileOperationsProgress *progress
 	/* No cancel button once the operation is done. */
 	gtk_dialog_set_response_sensitive (GTK_DIALOG (progress), GTK_RESPONSE_CANCEL, FALSE);
 
-	progress->details->delayed_close_timeout_id = gtk_timeout_add
+	progress->details->delayed_close_timeout_id = g_timeout_add
 		(MINIMUM_TIME_UP - time_up,
 		 delayed_close_callback,
 		 progress);
